@@ -4,7 +4,7 @@ use URI::WithBase;
 use URI::URL;
 use Exporter 'import';
 use vars qw(@EXPORT_OK $VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 @EXPORT_OK= qw(rebase_html rebase_css rebase_html_inplace rebase_css_inplace);
 
 =head1 NAME
@@ -140,11 +140,10 @@ sub relative_url {
 
 =head1 CAVEATS
 
-=head2 Does not handle C<< <base> >> tags
+=head2 Does handle the C<< <base> >> tag in a specific way
 
 If the HTML contains a C<< <base> >> tag, it's C<< href= >> attribute
-is not inspected but simply rewritten. Ideally, the C<< href= >> attribute
-should be identical to the URL passed to C<< rebase_html >>.
+is used as the page URL relative to which links are rewritten.
 
 =head2 Uses regular expressions to do all parsing
 
